/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/

/*
 * Ticked.h
 *
 *  Created on: Aug 6, 2009
 *      Author: jwienke
 */

#ifndef TICKED_H_
#define TICKED_H_

#include "MicroTimestamp.h"

namespace airobots {

/**
 * Base class to be used as mixin that enables data types to also have a
 * timestamp that encodes the creation time of the encapsulated data.
 *
 * @author jwienke
 */
class Ticked {
public:
	Ticked();

	MicroTimestamp getReadTime() const;
	timeval getReadTimeval() const;
	time_t getReadTimeSeconds() const;
	suseconds_t getReadTimeMicroSeconds() const;

	void setReadTime(timeval readTime);
	void setReadTime(MicroTimestamp readTime);

private:
	MicroTimestamp readTime;

};

}

#endif /* TICKED_H_ */
