/*
 * This file is part of Bielefeld Type Library (BTL).
 *
 * Copyright(c) Frederic Siepmann
 * http://opensource.cit-ec.de/projects/btl
 *
 * This file may be licensed under the terms of of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The development of this software was supported by the
 * Excellence Cluster EXC 277 Cognitive Interaction Technology.
 * The Excellence Cluster EXC 277 is a grant of the Deutsche
 * Forschungsgemeinschaft (DFG) in the context of the German
 * Excellence Initiative.
 *
 * Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
 * 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
 * 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
 */

#include "BoundingBox3D.h"
#include <math.h>

using namespace xmltio;
using namespace std;

namespace airobots {

std::string BoundingBox3D::getBaseTag() {
	return "BOUNDINGBOX3D";
}

std::string BoundingBox3D::getTemplate() {

	return "<" + getBaseTag() + "><GENERATOR/>" + Timestamp::getTemplate()
			+ "<ORIGIN>" + Point3D::getTemplate() + "</ORIGIN><ROTATION>"
			+ Rotation3D::getTemplate() + "</ROTATION><SIZE>"
			+ Point3D::getTemplate() + "</SIZE></" + getBaseTag() + ">";
}

BoundingBox3D::BoundingBox3D() {
}

BoundingBox3D::BoundingBox3D(const BoundingBox3D & data) :
		Type(data),
		origin(data.origin),
		rotation(data.rotation),
		size(data.size) {
}

BoundingBox3D::BoundingBox3D(string generator) :
		Type(generator) {
}

void BoundingBox3D::sanitizeLocation(xmltio::Location &loc) const {

}

void BoundingBox3D::fillInto(xmltio::Location &loc) const {

	Type::fillInto(loc);

	xmltio::Location originloc = loc[XPath("ORIGIN/POINT3D")];
	origin.fillInto(originloc);

	xmltio::Location sizeloc = loc[XPath("SIZE/POINT3D")];
	size.fillInto(sizeloc);

	xmltio::Location rotationloc = loc[XPath("ROTATION/ROTATION3D")];
	rotation.fillInto(rotationloc);
}

void BoundingBox3D::fromLocation(
		const xmltio::Location &loc_,
		BoundingBox3D &object) {

	Type::fromLocation(loc_, object);

	Point3D origin = extract<Point3D>(loc_[XPath("ORIGIN/POINT3D")]);
	object.origin = origin;

	Point3D size = extract<Point3D>(loc_[XPath("SIZE/POINT3D")]);
	object.size = size;

	Rotation3D rotation = extract<Rotation3D>(
			loc_[XPath("ROTATION/ROTATION3D")]);
	object.rotation = rotation;
}

bool BoundingBox3D::operator==(const BoundingBox3D &other) const {
	return rotation == other.rotation && origin == other.origin
			&& size == other.size;
}

void BoundingBox3D::setOrigin(const Point3D &origin) {
	this->origin = origin;
}

Point3D BoundingBox3D::getOrigin() const {
	return origin;
}

void BoundingBox3D::setRotation(const Rotation3D &rotation) {
	this->rotation = rotation;
}

BoundingBox3D::~BoundingBox3D() {
}

void BoundingBox3D::setWidth(float width, LengthUnit unit) {
	size.setX(width, unit);
}

float BoundingBox3D::getWidth(LengthUnit unit) const {
	return size.getX(unit);
}

void BoundingBox3D::setDepth(float depth, LengthUnit unit) {
	size.setY(depth, unit);
}

float BoundingBox3D::getDepth(LengthUnit unit) const {
	return size.getY(unit);
}

void BoundingBox3D::setHeight(float height, LengthUnit unit) {
	size.setZ(height, unit);
}

float BoundingBox3D::getHeight(LengthUnit unit) const {
	return size.getZ(unit);
}

Rotation3D BoundingBox3D::getRotation() const {
	return rotation;
}

}
