/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/

/*
 * KatanaGripperData.h
 *
 *  Created on: May 25, 2010
 *      Author: ttoenige
 */

#ifndef KATANAGRIPPERDATA_H_
#define KATANAGRIPPERDATA_H_

#include "../../Type.h"
namespace airobots
{

class KatanaGripperData: public Type
{
public:
	static std::string getBaseTag();

	static std::string getTemplate();

	KatanaGripperData();

	double getForceLeftInsideFar() const;
	double getForceLeftInsideNear() const;
	double getForceRightInsideFar() const;
	double getForceRightInsideNear() const;
	double getInfraredLeftFront() const;
	double getInfraredLeftInsideFar() const;
	double getInfraredLeftInsideNear() const;
	double getInfraredLeftOutside() const;
	double getInfraredMiddle() const;
	double getInfraredRightFront() const;
	double getInfraredRightInsideFar() const;
	double getInfraredRightInsideNear() const;
	double getInfraredRightOutside() const;

	void setForceLeftInsideFar(double forceLeftInsideFar);
	void setForceLeftInsideNear(double forceLeftInsideNear);
	void setForceRightInsideFar(double forceRightInsideFar);
	void setForceRightInsideNear(double forceRightInsideNear);
	void setInfraredLeftFront(double infraredLeftFront);
	void setInfraredLeftInsideFar(double infraredLeftInsideFar);
	void setInfraredLeftInsideNear(double infraredLeftInsideNear);
	void setInfraredLeftOutside(double infraredLeftOutside);
	void setInfraredMiddle(double infraredMiddle);
	void setInfraredRightFront(double infraredRightFront);
	void setInfraredRightInsideFar(double infraredRightInsideFar);
	void setInfraredRightInsideNear(double infraredRightInsideNear);
	void setInfraredRightOutside(double infraredRightOutside);

	void sanitizeLocation(xmltio::Location &loc) const;
	void fillInto(xmltio::Location &loc) const;
	static void fromLocation(const xmltio::Location &loc, KatanaGripperData &type);

private:
	double forceRightInsideNear;
	double forceRightInsideFar;
	double infraredRightOutside;
	double infraredRightFront;
	double infraredRightInsideNear;
	double infraredRightInsideFar;

	double forceLeftInsideNear;
	double forceLeftInsideFar;
	double infraredLeftOutside;
	double infraredLeftFront;
	double infraredLeftInsideNear;
	double infraredLeftInsideFar;

	double infraredMiddle;

};

}
#endif /* KATANAGRIPPERDATA_H_ */
