/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/

/*
 * CameraInfo.h
 *
 *  Created on: Sep 13, 2010
 *      Author: ltwardon
 */

#ifndef CAMERAINFO_H_
#define CAMERAINFO_H_
#include "../../units/UnitConverter.h"

#include <map>

using namespace std;

namespace airobots{

class CameraInfo {

public:

	enum CameraModel{
		SONY_EVI_D31,
		LOGITECH_PRO_9000,
		POINTGRAY_GRAS_20S4C_C_0_3M,
		POINTGRAY_GRAS_20S4C_C_1_4M,
		POINTGRAY_GRAS_20S4C_C_2_0M
	};

	static CameraInfo getInfo(CameraModel model);
	static double calculateAngleOfView(CameraModel camera, double zoom);

	CameraInfo();
	CameraInfo(int maxZoomFactor, double minAngleOfViewH,
			double maxAngleOfViewH, int resolutionX, int resolutionY,
			double minAnglePan, double maxAnglePan, double minAngleTilt,
			double maxAngleTilt,AngleUnit aU);
	double getMaxAngleOfViewH(AngleUnit aU) const;
	double getMaxAnglePan(AngleUnit aU) const;
	double getMaxAngleTilt(AngleUnit aU) const;
	int getMaxZoomFactor() const;
	double getMinAngleOfViewH(AngleUnit aU) const;
	double getMinAnglePan(AngleUnit aU) const;
	double getMinAngleTilt(AngleUnit aU) const;
	int getResolutionX() const;
	int getResolutionY() const;

private:

    static const map<CameraModel, CameraInfo> info;
	static map<CameraModel, CameraInfo> createInfo();
	static const AngleUnit iAU = RADIAN;

	int maxZoomFactor;
	double minAngleOfViewH;
	double maxAngleOfViewH;
	double minAnglePan;
	double maxAnglePan;
	double minAngleTilt;
	double maxAngleTilt;
	int resolutionX;
	int resolutionY;

};

}

#endif /* CAMERAINFO_H_ */
