/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/

/*
 * ROSCostmapConfiguration.cpp
 *
 *  Created on: May 31, 2012
 *      Author: pdressel
 */

#include "ROSMoveBaseConfiguration.h"

using namespace std;
using namespace airobots;
using namespace xmltio;

namespace airobots {
    
    const std::string ROSMoveBaseConfiguration::MOVEBASE_CONFIGURATION_TAG = "MOVEBASECONFIGURATION";
    
    const std::string ROSMoveBaseConfiguration::BASE_GLOBAL_PLANNER_ATTRIBUTE = "base_global_planner";
    const std::string ROSMoveBaseConfiguration::BASE_LOCAL_PLANNER_ATTRIBUTE = "base_local_planner";
    const std::string ROSMoveBaseConfiguration::PLANNER_FREQUENCY_ATTRIBUTE = "planner_frequency";
    const std::string ROSMoveBaseConfiguration::CONTROLLER_FREQUENCY_ATTRIBUTE = "controller_frequency";
    const std::string ROSMoveBaseConfiguration::PLANNER_PATIENCE_ATTRIBUTE = "planner_patience";
    const std::string ROSMoveBaseConfiguration::CONTROLLER_PATIENCE_ATTRIBUTE = "controller_patience";
    const std::string ROSMoveBaseConfiguration::CONSERVATIVE_RESET_DIST_ATTRIBUTE = "conservative_reset_dist";
    const std::string ROSMoveBaseConfiguration::RECOVERY_BEHAVIOR_ENABLED_ATTRIBUTE = "recovery_behavior_enabled";
    const std::string ROSMoveBaseConfiguration::CLEARING_ROTATION_ALLOWED_ATTRIBUTE = "clearing_rotation_allowed";
    const std::string ROSMoveBaseConfiguration::SHUTDOWN_COSTMAPS_ATTRIBUTE = "shutdown_costmaps";
    const std::string ROSMoveBaseConfiguration::OSCILLATION_TIMEOUT_ATTRIBUTE = "oscillation_timeout";
    const std::string ROSMoveBaseConfiguration::OSCILLATION_DISTANCE_ATTRIBUTE = "oscillation_distance";
    const std::string ROSMoveBaseConfiguration::RESTORE_DEFAULTS_ATTRIBUTE = "restore_defaults";
    
    ROSMoveBaseConfiguration::ROSMoveBaseConfiguration()
    {
        this->base_global_planner = "";
        this->base_local_planner = "";
        this->clearing_rotation_allowed = false;
        this->conservative_reset_dist = 0.0;
        this->controller_frequency = 0.0;
        this->controller_patience = 0.0;
        this->oscillation_distance = 0.0;
        this->oscillation_timeout = 0.0;
        this->planner_frequency = 0.0;
        this->planner_patience = 0.0;
        this->recovery_behavior_enabled = false;
        this->restore_defaults = false;
        this->shutdown_costmaps = false;
    }
    
    string ROSMoveBaseConfiguration::getBaseTag()
    {
        return ROSDynamicConfiguration::getBaseTag();
    }
    
    string ROSMoveBaseConfiguration::getTemplate()
    {        
    	return "<" + getBaseTag() + ">"		
		+ airobots::Timestamp::getTemplate()
                + "<GENERATOR/>"
		+ "<" + MOVEBASE_CONFIGURATION_TAG + " " + 
                        + "base_global_planner=\"\" "
                        + "base_local_planner=\"\" " 
                        + "clearing_rotation_allowed=\"\" "
                        + "conservative_reset_dist=\"\" " 
                        + "controller_frequency=\"\" "
                        + "controller_patience=\"\" " 
                        + "oscillation_distance=\"\" "
                        + "oscillation_timeout=\"\" " 
                        + "planner_frequency=\"\" "
                        + "planner_patience=\"\" " 
                        + "recovery_behavior_enabled=\"\" "
                        + "restore_defaults=\"\" " 
                        + "shutdown_costmaps=\"\" />"  
		+ "</" + getBaseTag() + ">";
    }
    
    void ROSMoveBaseConfiguration::sanitizeLocation(xmltio::Location &loc) const
    {
        ROSDynamicConfiguration::sanitizeLocation(loc);
    }    
    
    void ROSMoveBaseConfiguration::fillInto(xmltio::Location &loc) const
    {
        string prefix = MOVEBASE_CONFIGURATION_TAG 
                + ROSDynamicConfiguration::X_PATH_SEPARATOR 
                + ROSDynamicConfiguration::ATTRIBUTE_PREFIX;       
        
        Type::fillInto(loc);
        
        loc[XPath(prefix + BASE_GLOBAL_PLANNER_ATTRIBUTE)]      = this->base_global_planner;
	loc[XPath(prefix + BASE_LOCAL_PLANNER_ATTRIBUTE)]       = this->base_local_planner;
        loc[XPath(prefix + CLEARING_ROTATION_ALLOWED_ATTRIBUTE)]= this->clearing_rotation_allowed == 1 ? ROSDynamicConfiguration::TRUE_STRING : ROSDynamicConfiguration::FALSE_STRING;
        loc[XPath(prefix + CONSERVATIVE_RESET_DIST_ATTRIBUTE)]  = this->conservative_reset_dist;
        loc[XPath(prefix + CONTROLLER_FREQUENCY_ATTRIBUTE)]     = this->controller_frequency;
        loc[XPath(prefix + CONTROLLER_PATIENCE_ATTRIBUTE)]      = this->controller_patience;
        loc[XPath(prefix + OSCILLATION_DISTANCE_ATTRIBUTE)]     = this->oscillation_distance;
        loc[XPath(prefix + OSCILLATION_TIMEOUT_ATTRIBUTE)]      = this->oscillation_timeout;
        loc[XPath(prefix + PLANNER_FREQUENCY_ATTRIBUTE)]        = this->planner_frequency;
        loc[XPath(prefix + PLANNER_PATIENCE_ATTRIBUTE)]         = this->planner_patience;
        loc[XPath(prefix + RESTORE_DEFAULTS_ATTRIBUTE)]= this->restore_defaults == 1 ? ROSDynamicConfiguration::TRUE_STRING : ROSDynamicConfiguration::FALSE_STRING;
        loc[XPath(prefix + RECOVERY_BEHAVIOR_ENABLED_ATTRIBUTE)]= this->recovery_behavior_enabled == 1 ? ROSDynamicConfiguration::TRUE_STRING : ROSDynamicConfiguration::FALSE_STRING;
        loc[XPath(prefix + SHUTDOWN_COSTMAPS_ATTRIBUTE)]        = this->shutdown_costmaps == 1 ? ROSDynamicConfiguration::TRUE_STRING : ROSDynamicConfiguration::FALSE_STRING;
    } 
    
    void ROSMoveBaseConfiguration::fromLocation(const xmltio::Location &loc, ROSMoveBaseConfiguration &config)
    {
        string prefix = MOVEBASE_CONFIGURATION_TAG 
                + ROSDynamicConfiguration::X_PATH_SEPARATOR 
                + ROSDynamicConfiguration::ATTRIBUTE_PREFIX;
	
        
        Type::fromLocation(loc, config);
        
        config.setBaseGlobalPlanner(            extract<string>(loc[XPath(prefix + BASE_GLOBAL_PLANNER_ATTRIBUTE)]));
	config.setBaseLocalPlanner(             extract<string>(loc[XPath(prefix + BASE_LOCAL_PLANNER_ATTRIBUTE)]));
        
        string clearingRotationAllowedString    = extract<string>(loc[XPath(prefix + CLEARING_ROTATION_ALLOWED_ATTRIBUTE)]);
        config.setClearingRotationAllowed(clearingRotationAllowedString.compare(TRUE_STRING) == 0 ? true : false);
        
        config.setConservativeResetDist(        extract<double>(loc[XPath(prefix + CONSERVATIVE_RESET_DIST_ATTRIBUTE)]));
        config.setControllerFrequency(          extract<double>(loc[XPath(prefix + CONTROLLER_FREQUENCY_ATTRIBUTE)]));
        config.setControllerPatience(           extract<double>(loc[XPath(prefix + CONTROLLER_PATIENCE_ATTRIBUTE)]));
        config.setOscillationDistance(          extract<double>(loc[XPath(prefix + OSCILLATION_DISTANCE_ATTRIBUTE)]));
        config.setOscillationTimeout(           extract<double>(loc[XPath(prefix + OSCILLATION_TIMEOUT_ATTRIBUTE)]));
        config.setPlannerFrequency(             extract<double>(loc[XPath(prefix + PLANNER_FREQUENCY_ATTRIBUTE)]));   
        config.setPlannerPatience(              extract<double>(loc[XPath(prefix + PLANNER_PATIENCE_ATTRIBUTE)]));
        
        string recoveryBehaviorEnabledString    = extract<string>(loc[XPath(prefix + RECOVERY_BEHAVIOR_ENABLED_ATTRIBUTE)]);
        config.setRecoveryBehaviorEnabled(recoveryBehaviorEnabledString.compare(TRUE_STRING) == 0 ? true : false);                
        string restoreDefaultsString            = extract<string>(loc[XPath(prefix + RESTORE_DEFAULTS_ATTRIBUTE)]);
        config.setRestoreDefaults(restoreDefaultsString.compare(TRUE_STRING) == 0 ? true : false);
        string shutdownCostmapsString           = extract<string>(loc[XPath(prefix + SHUTDOWN_COSTMAPS_ATTRIBUTE)]);
        config.setShutdownCostmaps(shutdownCostmapsString.compare(TRUE_STRING) == 0 ? true : false);        
    }    
}