/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/

/*
 * Legs.h
 *
 *  Created on: Aug 18, 2009
 *      Author: jwienke
 */

#ifndef LEGS_H_
#define LEGS_H_

#include "../../Type.h"
#include "Percept.h"
#include "../../units/UnitConverter.h"

namespace airobots {

/**
 * Leg percept.
 *
 * @author jwienke
 */
class Legs: public Percept {

public:

	static std::string getBaseTag();
	static std::string getTemplate();
	static std::string getPerceptName();

	Legs();
	virtual ~Legs();

	float getAngle(AngleUnit angleUnit) const;
	void setAngle(float angle, AngleUnit angleUnit);

	float getDistance(LengthUnit lengthUnit) const;
	void setDistance(float distance,LengthUnit lengthUnit);

	float getAngleVariance(AngleUnit angleUnit) const;
	void setAngleVariance(float angleVariance,AngleUnit angleUnit);

	float getDistanceVariance(LengthUnit lengthUnit) const;
	void setDistanceVariance(float distanceVariance,LengthUnit lengthUnit);

	int getNumInvovled() const;
	void setNumInvolved(int numInvovled);

	int getInvolved1() const;
	void setInvolved1(int involved);

	int getInvolved2() const;
	void setInvolved2(int involved);

	bool isPair() const;
	void setPair(bool isPair);

	bool operator==(const Legs &other) const;

	void sanitizeLocation(xmltio::Location &loc) const;
	void fillInto(xmltio::Location &loc) const;
	static void fromLocation(const xmltio::Location &loc, Legs &type);

private:

	float angle;
	float distance;
	float angleVariance;
	float distanceVariance;
	int numInvolved;
	int involved[2];
	bool pair;

};

std::ostream& operator<<(std::ostream& o, Legs const& legs);

}

#endif /* LEGS_H_ */
