/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/

/* -*- mode: C++; tab-width: 4; c-basic-offset: 4; c-file-offsets: ((substatement-open . 0)) -*- */
/**
 * @file     laserdata.h
 * @author   Erik Weitnauer, Thorsten Spexard
 * @date     15.08.2005
 * @brief    defining and converting laser data in C++ stucts and XML
 */

#ifndef LASERDATA_CPP
#define LASERDATA_CPP

#include <string>
#include <vector>

#include <sys/time.h>

#include <xmltio/xmltio.hpp>

#include "../../units/LengthUnit.h"
#include "../../Type.h"
#include "../common/Ticked.h"

namespace airobots {

/**
 * C++ struct for laser data
 */
class LaserData: public Type, public Ticked {

public:

	static std::string getBaseTag();

	static std::string getTemplate();

	LaserData();
        LaserData(const LaserData &l);

	unsigned int getNumLaserPoints() const;

	const std::vector<float> getLaserPoints(LengthUnit u) const;
	void setLaserPoints(std::vector<float> laserPoints, LengthUnit u);

	void sanitizeLocation(xmltio::Location &loc) const;
	void fillInto(xmltio::Location &loc) const;
	static void fromLocation(const xmltio::Location &loc, LaserData &type);

private:

	/**
	 * Time at which these data were read.
	 */
	timeval readTime;

	/**
	 * array with distance measurements generated by laser range finder,
	 * distances in m relative to the robot
	 */
	std::vector<float> points;

	static LengthUnit iU;

};

}

#endif
