/*
 * This file is part of Bielefeld Type Library (BTL).
 * 
 * Copyright(c) Frederic Siepmann http://opensource.cit-ec.de/projects/btl
 * 
 * This file may be licensed under the terms of of the GNU Lesser General Public
 * License Version 3 (the ``LGPL''), or (at your option) any later version.
 * 
 * Software distributed under the License is distributed on an ``AS IS'' basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the LGPL for the
 * specific language governing rights and limitations.
 * 
 * You should have received a copy of the LGPL along with this program. If not,
 * go to http://www.gnu.org/licenses/lgpl.html or write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 * USA.
 * 
 * The development of this software was supported by the Excellence Cluster EXC
 * 277 Cognitive Interaction Technology. The Excellence Cluster EXC 277 is a
 * grant of the Deutsche Forschungsgemeinschaft (DFG) in the context of the
 * German Excellence Initiative.
 * 
 * Contributors: Florian Lier, Frederic Siepmann, Leon Ziegler, Matthias 
 * Schoepfer, Adriana-Victoria Dreyer, Agnes Swadzba, Andreas Kipp, Birte 
 * Carlmeyer, Christian Ascheberg, Daniel Nacke, Dennis Wigand, Günes Minareci, 
 * Hendrik ter Horst, Ingo Killmann, Jan Pöppel, Lukas Kettenbach, Michael 
 * Zeunert, Patrick Renner, Philipp Dresselhaus, Robin Schiewer, Sebastian 
 * Meyer zu Borgsen, Soufian Jebbara, Tobias Röhlig, Torben Toeniges, Tristan 
 * Walter, Viktor Losing, Viktor Richter
 */
package de.unibi.airobots.btl.data.asu;

/**
 * Contains all states of utterances.
 *
 * @author malinke
 */
public enum ProcessingStatus {

	/**
	 * Understood 0% of the words.
	 */
	NonUnderstanding(.0f),
	/**
	 * Understood lesser than 35% of the words.
	 */
	SparseUnderstanding(0.35f),
	/**
	 * Understood up to 75% of the words.
	 */
	PartialUnderstanding(0.75f),
	/**
	 * Understood more than 75% of the words.
	 */
	FullUnderstanding(1.0f);
	private final float maxRating;

	private ProcessingStatus(float maxRating) {
		this.maxRating = maxRating;
	}

	private boolean ratingAccepted(float rating) {
		return rating <= maxRating;
	}
//	public static ProcessingStatus forOldRating(final float rating) {
//		return forRating(rating);
//	}
//	public static ProcessingStatus forRating(final float rating) {
//		return NonUnderstanding;
//		final float UNDERSTANDING_LIMIT = 0.25f;
//		final float FULLUNDERSTANDING_LIMIT = 0.5f;
//		if (rating < UNDERSTANDING_LIMIT) {
//			return NonUnderstanding;
//		}
//		if (rating <= FULLUNDERSTANDING_LIMIT) {
//			return PartialUnderstanding;
//		}
//		assert rating > FULLUNDERSTANDING_LIMIT : "state eval error";
//		return FullUnderstanding;
//	}
/**
 * Returns the fitting state of understanding / rating.
 *
 * @param rating of an linked hypothesis
 * @return understanding state of utterance
 */
public static ProcessingStatus forRating(final float rating) {

		if (NonUnderstanding.ratingAccepted(rating)) {
			return NonUnderstanding;
		}
		if (SparseUnderstanding.ratingAccepted(rating)) {
			return SparseUnderstanding;
		}
		if (PartialUnderstanding.ratingAccepted(rating)) {
			return PartialUnderstanding;
		}

		if(FullUnderstanding.ratingAccepted(rating)) {
			return FullUnderstanding;
		}

		throw new AssertionError("state eval error");
	}

}
