/*
 * This file is part of Bielefeld Type Library (BTL).
 * 
 * Copyright(c) Frederic Siepmann http://opensource.cit-ec.de/projects/btl
 * 
 * This file may be licensed under the terms of of the GNU Lesser General Public
 * License Version 3 (the ``LGPL''), or (at your option) any later version.
 * 
 * Software distributed under the License is distributed on an ``AS IS'' basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the LGPL for the
 * specific language governing rights and limitations.
 * 
 * You should have received a copy of the LGPL along with this program. If not,
 * go to http://www.gnu.org/licenses/lgpl.html or write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 * USA.
 * 
 * The development of this software was supported by the Excellence Cluster EXC
 * 277 Cognitive Interaction Technology. The Excellence Cluster EXC 277 is a
 * grant of the Deutsche Forschungsgemeinschaft (DFG) in the context of the
 * German Excellence Initiative.
 * 
 * Contributors: Florian Lier, Frederic Siepmann, Leon Ziegler, Matthias 
 * Schoepfer, Adriana-Victoria Dreyer, Agnes Swadzba, Andreas Kipp, Birte 
 * Carlmeyer, Christian Ascheberg, Daniel Nacke, Dennis Wigand, Günes Minareci, 
 * Hendrik ter Horst, Ingo Killmann, Jan Pöppel, Lukas Kettenbach, Michael 
 * Zeunert, Patrick Renner, Philipp Dresselhaus, Robin Schiewer, Sebastian 
 * Meyer zu Borgsen, Soufian Jebbara, Tobias Röhlig, Torben Toeniges, Tristan 
 * Walter, Viktor Losing, Viktor Richter
 */
package de.unibi.airobots.btl.data.speechrec;

import nu.xom.Attribute;
import nu.xom.Element;
import nu.xom.Node;
import nu.xom.Nodes;
import de.unibi.airobots.btl.Type;
import de.unibi.airobots.btl.data.common.ElementParser;
import de.unibi.airobots.btl.data.person.Percept;
import de.unibi.airobots.btl.units.*;

public class Voice extends Type implements Percept {

	static private AngleUnit iAU = AngleUnit.RADIAN;
	static private TimeUnit iTU = TimeUnit.MICROSECONDS;

	@Override
	public String getPerceptName() {
		return "voice";
	}

	public static String getBaseTag() {
		return "VOICE";
	}

	public static void fromElement(Element element, Voice type) {

		Type.fromElement(element, type);

		Nodes nodes = element.query("*");
		for (int i = 0; i < nodes.size(); i++) {
			Node node = nodes.get(i);
			if (node instanceof Element) {
				Element elem = (Element) node;
				if (elem.getLocalName().equals("POSITION")) {
					type.setAngle((float) ElementParser
							.getDoubleAttributeValue(elem, "angle"), iAU);
					type.setAngleVariance((float) ElementParser
							.getDoubleAttributeValue(elem, "angleVariance"),
							iAU);
					type.setRuntimeDifference((long) ElementParser
							.getLongAttributeValue(elem, "runtimeDifferenceMicro"),
							iTU);
					type.setRuntimeDifferenceVariance((long) ElementParser
							.getLongAttributeValue(elem,
									"runtimeDifferenceVarianceMicro"), iTU);
				}
			}
		}

	}

	public void fillInto(Element parent) {

		super.fillInto(parent);

		Element posElement = new Element("POSITION");
		parent.appendChild(posElement);
		posElement.addAttribute(new Attribute("" + "angle", String
				.valueOf(getAngle(iAU))));
		posElement.addAttribute(new Attribute("" + "angleVariance", String
				.valueOf(getAngleVariance(iAU))));
		posElement.addAttribute(new Attribute("" + "runtimeDifferenceMicro", String
				.valueOf(getRuntimeDifference(iTU))));
		posElement.addAttribute(new Attribute("" + "runtimeDifferenceVarianceMicro",
				String.valueOf(getRuntimeDifferenceVariance(iTU))));

	}

	public void setAngle(float angle, AngleUnit aU) {
		this.angle = UnitConverter.convert(angle, aU, iAU);
	}

	public float getAngle(AngleUnit aU) {
		return UnitConverter.convert(angle, iAU, aU);
	}

	public void setRuntimeDifference(long runtimeDifference, TimeUnit timeUnit) {
		this.runtimeDifferenceMicro = UnitConverter.convert(runtimeDifference,
				timeUnit, iTU);
	}

	public long getRuntimeDifference(TimeUnit timeUnit) {
		return UnitConverter.convert(runtimeDifferenceMicro, iTU, timeUnit);
	}

	public void setAngleVariance(float angleVariance, AngleUnit aU) {
		this.angleVariance = UnitConverter.convert(angleVariance, aU, iAU);
	}

	public float getAngleVariance(AngleUnit aU) {
		return UnitConverter.convert(angleVariance, iAU, aU);
	}

	public void setRuntimeDifferenceVariance(long runtimeDifferenceVariance,
			TimeUnit timeUnit) {
		this.runtimeDifferenceVarianceMicro = UnitConverter.convert(
				runtimeDifferenceVariance, timeUnit, iTU);
	}

	public long getRuntimeDifferenceVariance(TimeUnit timeUnit) {
		return UnitConverter.convert(runtimeDifferenceVarianceMicro, iTU,
				timeUnit);
	}

	public boolean equals(Voice other) {
		return (super.equals(other))
				&& (this.getAngle(iAU) == other.getAngle(iAU))
				&& (this.getAngleVariance(iAU) == other.getAngleVariance(iAU))
				&& (this.getRuntimeDifference(iTU) == other
						.getRuntimeDifference(iTU))
				&& (this.getRuntimeDifferenceVariance(iTU) == other
						.getRuntimeDifferenceVariance(iTU));
	}

	private float angle;
	private long runtimeDifferenceMicro;
	private float angleVariance;
	private long runtimeDifferenceVarianceMicro;

}
