/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/

/*
 * MovementDataTest.cpp
 *
 *  Created on: Jul 20, 2009
 *      Author: jwienke
 */

#include <boost/test/unit_test.hpp>
#include <boost/test/floating_point_comparison.hpp>

#include <exception>
#include <stdexcept>
#include <iostream>

#include <sys/time.h>
#include <time.h>

#include "btl/data/common/MicroTimestamp.h"

using namespace airobots;
using namespace std;
using namespace xmltio;

static const double TOLERANCE = 0.0001;

BOOST_AUTO_TEST_SUITE(MicroTimestampTest)

BOOST_AUTO_TEST_CASE(testSelfCompatibility) {

	try {

		timeval now;
		gettimeofday(&now, NULL);
		MicroTimestamp original(now);

		Location originalLoc(MicroTimestamp::getTemplate(), MicroTimestamp::getBaseTag());
		originalLoc = original;

		MicroTimestamp parsed = extract<MicroTimestamp>(originalLoc);

		BOOST_REQUIRE_EQUAL(parsed.getSeconds(), original.getSeconds());
		BOOST_REQUIRE_EQUAL(parsed.getMicroSeconds(), original.getMicroSeconds());

	} catch (std::exception e) {
		BOOST_FAIL(string("Caught exception: ") + e.what());
	}

}

BOOST_AUTO_TEST_CASE(testTimevalFromDouble) {

	timeval now;
	gettimeofday(&now, NULL);

	double time = (double) now.tv_sec + (double) (now.tv_usec / 1000000.0);

	timeval converted = MicroTimestamp::timevalFromDouble(time);

	BOOST_REQUIRE_EQUAL(now.tv_sec, converted.tv_sec);
	BOOST_REQUIRE_CLOSE((double) now.tv_usec, (double) converted.tv_usec, 10.0);

}

BOOST_AUTO_TEST_CASE(testUSecException) {

	BOOST_REQUIRE_THROW(MicroTimestamp kaputt(23, 1000001), std::domain_error);

	timeval wrong;
	wrong.tv_sec = 23;
	wrong.tv_usec = 1000001;

	BOOST_REQUIRE_THROW(MicroTimestamp kaputt2(wrong), std::domain_error);

}

BOOST_AUTO_TEST_SUITE_END()
