/*
 * This file is part of Bielefeld Type Library (BTL).
 *
 * Copyright(c) Frederic Siepmann
 * http://opensource.cit-ec.de/projects/btl
 *
 * This file may be licensed under the terms of of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The development of this software was supported by the
 * Excellence Cluster EXC 277 Cognitive Interaction Technology.
 * The Excellence Cluster EXC 277 is a grant of the Deutsche
 * Forschungsgemeinschaft (DFG) in the context of the German
 * Excellence Initiative.
 *
 * Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
 * 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
 * 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
 */

/*
 * MovementDataTest.cpp
 *
 *  Created on: Jul 20, 2009
 *      Author: jwienke
 */

#include <boost/test/unit_test.hpp>
#include <boost/test/floating_point_comparison.hpp>

#include  <iostream>

#include "btl/data/navigation/NavigationGoalData.h"
#include "../../utils.h"

using namespace airobots;
using namespace std;
using namespace xmltio;

static const double TOLERANCE = 0.0001;

BOOST_AUTO_TEST_SUITE(NavigationGoalDataTest)

BOOST_AUTO_TEST_CASE(testSelfCompatibility) {

	try {

		NavigationGoalData original("test", 230.34, -120, 0.623, 3.45, 0.2, NavigationGoalData::GLOBAL);
		original.setTimestamp(Timestamp(123, 456));

		Location originalLoc(NavigationGoalData::getTemplate(), NavigationGoalData::getBaseTag());
		originalLoc = original;

		NavigationGoalData parsed = extract<NavigationGoalData>(originalLoc);

		BOOST_REQUIRE_EQUAL(parsed.getGenerator(), original.getGenerator());
		BOOST_REQUIRE_EQUAL(parsed.getTimestamp(), original.getTimestamp());
		BOOST_REQUIRE_EQUAL(parsed.getType(), original.getType());
		BOOST_REQUIRE_CLOSE(parsed.getCoordinateTolerance(METER), original.getCoordinateTolerance(METER), TOLERANCE);
		BOOST_REQUIRE_CLOSE(parsed.getAngleTolerance(RADIAN), original.getAngleTolerance(RADIAN), TOLERANCE);
		BOOST_REQUIRE_CLOSE(parsed.getTheta(RADIAN), original.getTheta(RADIAN), TOLERANCE);
		BOOST_REQUIRE_CLOSE(parsed.getX(MILLIMETER), original.getX(MILLIMETER), TOLERANCE);
		BOOST_REQUIRE_CLOSE(parsed.getY(MILLIMETER), original.getY(MILLIMETER), TOLERANCE);

	} catch (xmltio::XMLTIO_Exception &e) {
		BOOST_FAIL(string("Caught exception: ") + e.what());
	} catch (std::exception &e) {
		BOOST_FAIL(string("Caught exception: ") + e.what());
	}

}

BOOST_AUTO_TEST_CASE(testFileCompatibility) {

	Location fileContents(readFile("NavigationGoal.xml"), NavigationGoalData::getBaseTag());
	NavigationGoalData parsed = extract<NavigationGoalData>(fileContents);

	BOOST_REQUIRE_EQUAL("test", parsed.getGenerator());
	BOOST_REQUIRE_EQUAL(12345, parsed.getTimestamp().getInserted());
	BOOST_REQUIRE_EQUAL(67890, parsed.getTimestamp().getUpdated());
	BOOST_REQUIRE_CLOSE((float) 234.5, parsed.getX(METER), 0.00001);
	BOOST_REQUIRE_CLOSE((float) -6345.42, parsed.getY(METER), 0.00001);
	BOOST_REQUIRE_CLOSE((float) 0.34, parsed.getTheta(RADIAN), 0.00001);
	BOOST_REQUIRE_CLOSE((float) 0.77, parsed.getCoordinateTolerance(METER), 0.00001);
	BOOST_REQUIRE_CLOSE((float) 0.5, parsed.getAngleTolerance(RADIAN), 0.00001);
	BOOST_REQUIRE_EQUAL(NavigationGoalData::GLOBAL, parsed.getType());

}

BOOST_AUTO_TEST_SUITE_END()
