/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/

/*
 * ObjectLocationListTest.cpp
 *
 *  Created on: Jun 1, 2010
 *      Author: lziegler
 */

#include <boost/test/unit_test.hpp>
#include <boost/test/floating_point_comparison.hpp>

#include <iostream>

#include <sys/time.h>
#include <time.h>

#include "btl/data/vision3d/SRCalibratedData.h"
#include "../../utils.h"

using namespace airobots;
using namespace std;
using namespace xmltio;

static const double TOLERANCE = 0.0001;

BOOST_AUTO_TEST_SUITE(SRCalibratedDataTest)

BOOST_AUTO_TEST_CASE(testSelfCompatibility) {

	SRCalibratedData original;

	original.setScope(SRCalibratedData::GLOBAL);

	Point3D p0 = Point3D(1.0f,2.0f,3.0f,MILLIMETER,Point3D::GLOBAL);
	Point3D p1 = Point3D(1.0f,2.0f,3.0f,MILLIMETER,Point3D::GLOBAL);
	Point3D p2 = Point3D(0.1f,0.2f,0.3f,MILLIMETER,Point3D::LOCAL);
	original.push_back(p0);
	original.push_back(p1);
	original.push_back(p2);

	Location originalLoc(SRCalibratedData::getTemplate(), SRCalibratedData::getBaseTag());
	originalLoc = original;

	SRCalibratedData parsed = extract<SRCalibratedData>(originalLoc);

	BOOST_REQUIRE_EQUAL(parsed.size(), original.size());
	BOOST_REQUIRE_EQUAL(parsed.getScope(), original.getScope());
	BOOST_REQUIRE_EQUAL(parsed[0].getX(), original[0].getX());
	BOOST_REQUIRE_EQUAL(parsed[0].getY(), original[0].getY());
	BOOST_REQUIRE_EQUAL(parsed[0].getZ(), original[0].getZ());
	BOOST_REQUIRE_EQUAL(parsed[0].getScope(), original[0].getScope());
	BOOST_REQUIRE_EQUAL(parsed[2].getX(), original[2].getX());
	BOOST_REQUIRE_EQUAL(parsed[2].getY(), original[2].getY());
	BOOST_REQUIRE_EQUAL(parsed[2].getZ(), original[2].getZ());
	BOOST_REQUIRE_EQUAL(parsed[2].getScope(), original[2].getScope());

}

BOOST_AUTO_TEST_CASE(testFileCompatibility) {

	SRCalibratedData original;

	original.setScope(SRCalibratedData::GLOBAL);

	Point3D p0 = Point3D(1.0f,2.0f,3.0f,MILLIMETER,Point3D::GLOBAL);
	Point3D p1 = Point3D(1.0f,2.0f,3.0f,MILLIMETER,Point3D::GLOBAL);
	Point3D p2 = Point3D(0.1f,0.2f,0.3f,MILLIMETER,Point3D::LOCAL);
	original.push_back(p0);
	original.push_back(p1);
	original.push_back(p2);

	Location fileContents(readFile("SRCalibratedData.xml"), SRCalibratedData::getBaseTag());
	SRCalibratedData parsed = extract<SRCalibratedData>(fileContents);

	BOOST_REQUIRE_EQUAL(parsed.size(), original.size());
	BOOST_REQUIRE_EQUAL(parsed.getScope(), original.getScope());
	BOOST_REQUIRE_EQUAL(parsed[0].getX(), original[0].getX());
	BOOST_REQUIRE_EQUAL(parsed[0].getY(), original[0].getY());
	BOOST_REQUIRE_EQUAL(parsed[0].getZ(), original[0].getZ());
	BOOST_REQUIRE_EQUAL(parsed[0].getScope(), original[0].getScope());
	BOOST_REQUIRE_EQUAL(parsed[2].getX(), original[2].getX());
	BOOST_REQUIRE_EQUAL(parsed[2].getY(), original[2].getY());
	BOOST_REQUIRE_EQUAL(parsed[2].getZ(), original[2].getZ());
	BOOST_REQUIRE_EQUAL(parsed[2].getScope(), original[2].getScope());

}

BOOST_AUTO_TEST_SUITE_END()
