
package de.unibi.airobots.btl.data.command;

import de.unibi.airobots.btl.TestUtils;
import de.unibi.airobots.btl.data.speechrec.GrammarNonTerminal;
import nu.xom.Builder;
import nu.xom.Document;
import nu.xom.Element;
import nu.xom.ParsingException;
import org.apache.log4j.Logger;
import static org.junit.Assert.assertEquals;
import org.junit.Test;

/**
 *
 * @author ikillman
 */
public class CommandDataTest {
    
    private Logger logger = Logger.getLogger(getClass());

	@Test
	public void selfCompatibility() throws ParsingException {

            CommandData command = new CommandData();
            final long timestamp = System.currentTimeMillis();
            command.setTimestamp(timestamp);
            command.setAction("bring");
            command.setLocation("appliance");
            command.setObject("drink");
            GrammarNonTerminal tree = new GrammarNonTerminal();
            command.setTree(tree);

            Document document = new Document(new Element(CommandData.getBaseTag()));
            command.fillInto(document.getRootElement());

            logger.info(document.toXML());

            CommandData parsed = new CommandData();
            CommandData.fromElement(document.getRootElement(), parsed);


            assertEquals(command.getAction(), parsed.getAction());
            assertEquals(command.getLocation(), parsed.getLocation());
            assertEquals(command.getObject(), parsed.getObject());
            assertEquals(command.getTree(), parsed.getTree());
		
	}

	@Test
	public void fileCompatibility() throws Exception {
		
            CommandData command = new CommandData();
            final long timestamp = System.currentTimeMillis();
            command.setTimestamp(timestamp);
            command.setAction("bring");
            command.setLocation("appliance");
            command.setObject("drink");
            GrammarNonTerminal tree = new GrammarNonTerminal();
            command.setTree(tree);

            Builder parser = new Builder();
            Document doc = parser.build(TestUtils.makeTestFileName("CommandData.xml"));

            CommandData parsed = new CommandData();
            CommandData.fromElement(doc.getRootElement(), parsed);

            assertEquals(doc.getRootElement().getLocalName(), CommandData.getBaseTag());
            assertEquals("test", parsed.getGenerator());

            assertEquals(command.getAction(), parsed.getAction());
            assertEquals(command.getLocation(), parsed.getLocation());
            assertEquals(command.getObject(), parsed.getObject());
            assertEquals(command.getTree(), parsed.getTree());
            

	}
    
}
