/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/
package de.unibi.airobots.btl.data.object;

import static org.junit.Assert.*;
import nu.xom.Builder;
import nu.xom.Document;
import nu.xom.Element;

import org.apache.log4j.Logger;
import org.junit.Test;

import de.unibi.airobots.btl.TestUtils;
import de.unibi.airobots.btl.Type;
import de.unibi.airobots.btl.data.common.Timestamp;
import de.unibi.airobots.btl.data.object.ObjectData;

/**
 * Test cases for {@link Type}.
 * 
 * @author jwienke
 */
public class ObjectDataTest {

	private Logger logger = Logger.getLogger(getClass());

	@Test
	public void selfCompatibility() throws Exception {
		
		final long timestamp = System.currentTimeMillis();
		
		ObjectData original = new ObjectData();
		
		
		ObjectData.Hypothesis hyp = new ObjectData.Hypothesis();
		hyp.setTimestamp(timestamp);
		hyp.setGenerator("test");
		hyp.setReliability(0.1);
		hyp.setClassLabel("testclass");
		
		original.addHypothesis(hyp);

		Document doc = new Document(new Element(ObjectData.getBaseTag()));
		original.fillInto(doc.getRootElement());
		logger.info(doc.toXML());

		ObjectData parsed = new ObjectData();
		ObjectData.fromElement(doc.getRootElement(), parsed);
		ObjectData.Hypothesis parsedHyp = parsed.getHypotheses().iterator().next();

		assertEquals(hyp.getGenerator(), parsedHyp.getGenerator());
		assertEquals(hyp.getTimestamp(), parsedHyp.getTimestamp());
		assertEquals(hyp.getClassLabel(), parsedHyp.getClassLabel());
		assertEquals(hyp.getReliability(), parsedHyp.getReliability(), 0.0001);

	}

	@Test
	public void fileCompatibility() throws Exception {

		Builder parser = new Builder();
		Document doc = parser.build(TestUtils
				.makeTestFileName("ObjectData.xml"));

		ObjectData parsed = new ObjectData();
		ObjectData.fromElement(doc.getRootElement(), parsed);
		ObjectData.Hypothesis parsedHyp = parsed.getHypotheses().iterator().next();
		
		assertEquals(doc.getRootElement().getLocalName(), ObjectData
				.getBaseTag());

		assertEquals("BoostDetector", parsedHyp.getGenerator());
		assertEquals(new Timestamp(253543797l, 253543712l), parsedHyp
				.getTimestamp());
		assertEquals("smacks", parsedHyp.getClassLabel());
		assertEquals(0.6, parsedHyp.getReliability(), 0.002);

	}

}
