/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/
package de.unibi.airobots.btl.data.vision3d;

import static org.junit.Assert.*;
import nu.xom.Document;
import nu.xom.Element;

import org.junit.Test;

import de.unibi.airobots.btl.List;
import de.unibi.airobots.btl.Type;
import de.unibi.airobots.btl.data.vision2d.RegionData.Scope;
import de.unibi.airobots.btl.data.vision3d.PlaneData;

/**
 * Test cases for {@link Type}.
 * 
 * @author ltwardon, lziegler
 */
public class PlaneListTest {

	@Test
	public void selfCompatibility() throws Exception {

		PlaneData plane1 = new PlaneData();
		plane1.setScope(Scope.LOCAL);
		PlaneData plane2 = new PlaneData();
		plane2.setScope(Scope.LOCAL);
		
		List<PlaneData> original = new List<PlaneData>(PlaneData.class);
		original.add(plane1);
		original.add(plane2);
		
		Document doc = new Document(new Element(List.getBaseTag(PlaneData.class)));
		original.fillInto(doc.getRootElement());

		List<PlaneData> parsed = new List<PlaneData>(PlaneData.class);
		List.fromElement(doc.getRootElement(), parsed);

		assertEquals(original.size(), parsed.size());
		assertEquals(original.get(0).getScope(), parsed.get(0).getScope());
		assertEquals(original.get(1).getScope(), parsed.get(1).getScope());
	}

}
